OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola.",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte de  que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Recipient" : "Destinatario",
    "Too many redirects. Aborting ..." : "Demasiadas redirecciones. Cancelando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remoto no dio acceso al calendario (error HTTP {%s})",
    "Error connecting to remote server" : "Error al conectar con el servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error al solicitar recurso al servidor remoto. Esto puede estar relacionado con un error de certificado",
    "Error requesting resource on remote server" : "Error al pedir recurso en servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Habitación",
    "Unknown" : "Desconocido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "No asistir",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está en una zona horaria desconocida ({tz}), volviendo a UTC",
    "Please create a calendar first." : "Por favor, cree primero un calendario.",
    "New event" : "Nuevo evento",
    "CalDAV address for clients" : "Dirección CalDAV para los clientes",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos de este calendario están rotos. Por favor revise la consola JavScript para más información.",
    "Share Calendar" : "Compartir calendario",
    "Shared" : "Compartido",
    "Could not save WebCal-calendar" : "No se ha podido guardar el calendario WebCal",
    "WebDAV address for subscriptions" : "Dirección WebDAV para los subscriptores",
    "Email sent." : "Correo enviado.",
    "Could not send your email." : "No se ha podido enviar tu correo.",
    "group" : "grupo",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repetición",
    "When shared show full event" : "Mostrar el evento completo al compartir",
    "When shared show only busy" : "Mostrar solamente ocupado al compartir",
    "When shared hide this event" : "Ocultar este evento al compartir",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Cancelled" : "Cancelado",
    "Please add a title." : "Por favor, añade un título.",
    "Please select a calendar." : "Por favor, selecciona un calendario.",
    "The event can not end before it starts." : "El evento no puede terminar antes de empezar.",
    "Global" : "Global",
    "None" : "Ninguno",
    "Every day" : "Cada día",
    "Every week" : "Cada semana",
    "Every month" : "Cada mes",
    "Every year" : "Cada año",
    "never" : "nunca",
    "after" : "después de",
    "How about getting started by importing some calendars?" : "¿Qué le parece empezar importando algún calendario?",
    "At time of event" : "A la hora del evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personal",
    "Audio" : "Audio",
    "Email" : "Correo electrónico",
    "Pop-up" : "Ventana emergente",
    "sec" : "seg.",
    "min" : "min.",
    "hours" : "horas",
    "days" : "días",
    "week" : "semana",
    "before" : "antes",
    "start" : "comienzo",
    "end" : "fin",
    "Editing reminders of unknown type not supported." : "La edición de recordatorios de tipo desconocido no tiene respaldo.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported {imported} objects" : "Se han importado con éxito {imported} objetos",
    "Imported {imported} out of {all}, skipped one duplicate" : "Se han importado {imported} de un total de {all}, se ha omitido un duplicado",
    "Imported {imported} out of {all}, one failure" : "Se han importado {imported} de un total de {all}, un fallo",
    "Imported {imported} out of {all}, {errors} failures" : "Se han importado {imported} de un total de {all}, {errors} fallos",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Se han importado {imported} de un un total de {all}, se han omitido {duplicates} duplicados",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Se han importado {imported} de un total de {all}, {errors} fallos, se han omitido {duplicates} duplicados",
    "Audio alarm {time} before the event starts" : "Alarma sonora {time} antes de que comience el evento",
    "Pop-up {time} before the event starts" : "Ventana de aviso {time} antes de que comience el evento",
    "Email {time} before the event starts" : "Correo electrónico {time} antes de que comience el evento",
    "None {time} before the event starts" : "Nada {time} antes de que comience el evento",
    "{type} {time} before the event starts" : "{type} {time} antes de que inicie el evento",
    "Audio alarm {time} before the event ends" : "Alarma sonora {time} antes de que termine el evento",
    "Pop-up {time} before the event ends" : "Ventana de aviso {time} antes de que termine el evento",
    "Email {time} before the event ends" : "Correo electrónico {time} antes de que termine el evento",
    "None {time} before the event ends" : "Nada {time} antes de que termine el evento",
    "{type} {time} before the event ends" : "{type} {time} antes de que termine el evento",
    "Audio alarm {time} after the event starts" : "Alarma sonora {time} después de que comience el evento",
    "Pop-up {time} after the event starts" : "Ventana de aviso {time} después de que comience el evento",
    "Email {time} after the event starts" : "Correo electrónico {time} después de que comience el evento",
    "None {time} after the event starts" : "Nada {} después de que comience el evento",
    "{type} {time} after the event starts" : "{type} {time} después de que inicie el evento",
    "Audio alarm {time} after the event ends" : "Alarma sonora {time} después de que termine el evento",
    "Pop-up {time} after the event ends" : "Ventana de aviso {time} después de que termine el evento",
    "Email {time} after the event ends" : "Correo electrónico {time} después de que termine el evento",
    "None {time} after the event ends" : "Nada {time} después de que termine el evento",
    "{type} {time} after the event ends" : "{type} {time} después de que termine el evento",
    "Audio alarm at the event's start" : "Alarma sonora al comienzo del evento",
    "Pop-up at the event's start" : "Ventana de aviso al comienzo del evento",
    "Email at the event's start" : "Correo electrónico al comienzo del evento",
    "None at the event's start" : "Nada al comienzo del evento",
    "{type} at the event's start" : "{type} al inicio del evento",
    "Audio alarm at the event's end" : "Alarma sonora al final del evento",
    "Pop-up at the event's end" : "Ventana de aviso al final del evento",
    "Email at the event's end" : "Correo electrónico al final del evento",
    "None at the event's end" : "Nada al final del evento",
    "{type} at the event's end" : "{type} al final del evento",
    "Audio alarm at {time}" : "Alarma sonora a las {time}",
    "Pop-up at {time}" : "Ventana de aviso a las {time}",
    "Email at {time}" : "Correo electrónico a las {time}",
    "None at {time}" : "Nada a las {time}",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Please enter a valid WebCal-URL" : "Por favor introduzca una URL valida WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Error grave en el proxy webcal. Por favor, póngase en contacto con el administrador para más información.",
    "Title of the Event" : "Título del evento",
    "Starts" : "Comienza",
    "Ends" : "Finaliza",
    "All day Event" : "Todo el día",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "More ..." : "Más ...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Close" : "Cerrar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Event status" : "Estado del evento",
    "Visibility when sharing" : "Visibilidad cuando se comparte",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s ha publicado el calendario %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Queremos informarle de que %s ha publicado el calendario {boldstart}%s{boldend}.",
    "Click here to access it" : "Pincha aquí para obtener acceso a esto",
    "We wanted to inform you that %s has published the calendar %s." : "Queremos informarle de que %s ha publicado el calendario %s.",
    "Click on the link below to access it" : "Pincha en el enlace de abajo para tener acceso a esto",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Today" : "Hoy",
    "More" : "Más",
    "Edit" : "Editar",
    "Link" : "Enlace",
    "iCal link" : "Enlace iCal",
    "Download" : "Descargar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "can edit" : "puede editar",
    "Share link" : "Enlace compartido",
    "Public access" : "Acceso público",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send" : "Enviar",
    "New Calendar" : "Nuevo calendario",
    "Name" : "Nombre",
    "New Subscription" : "Nueva suscripción",
    "Go back" : "Atrás",
    "Go forward" : "Adelante",
    "Calendar does not exist" : "El calendario no existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "¿Quizás el enlace está equivocado o el calendario dejó de ser compartido?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Eliminar evento",
    "Save Event" : "Guardar evento",
    "Time" : "Hora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "veces cada",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Los recordatorios de correo todavía no se han implementado en el servidor, por lo que no se enviarán.",
    "Add" : "Añadir",
    "Email address of attendee" : "Correo electrónico del asistente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su correo electrónico en la configuración de su cuenta para agregar asistentes",
    "from" : "desde",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regla de repetición de eventos aún no está soportada.",
    "Support for advanced rules will be added with subsequent updates." : "El soporte para reglas avanzadas se añadirá en próximas actualizaciones. ",
    "Reset repeating rule" : "Reinicializar regla de repetición",
    "Repeat every ..." : "Repetir cada ...",
    "end repeat ..." : "finalizar repetir ...",
    "times" : "veces",
    "Import Calendars" : "Importar calendario",
    "Import canceled" : "Importación cancelada",
    "Analyzing calendar" : "Analizando calendario",
    "The file contains objects incompatible with the selected calendar" : "El archivo contiene objetos incompatibles con el calendario seleccionado",
    "New calendar" : "Nuevo calendario",
    "File is empty" : "El archivo está vacío",
    "Import scheduled" : "Importar horario",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartió el calendario <strong>%s</strong> contigo",
    "Embed" : "Insertar",
    "Iframe to integrate" : "Iframe para integrar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Ajustes & importar",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "No se seleccionó un calendario para importar",
    "Skip simple event editor" : "Omitir el editor de evento único",
    "Show week numbers" : "Mostrar numero de semana",
    "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
    "iOS/OS X CalDAV address" : "Direccion de calendario CalDAV iOS/OSX",
    "Subscribe" : "Suscribirse"
},
"nplurals=2; plural=(n != 1);");
